@@ -32,6 +32,7 @@ from calculate.install.distr import (Distributive, PartitionDistributive,
                                      MultiPartitions, PxeDistributive)
 
 from calculate.lib.cl_lang import setLocalTranslate, _
+from calculate.install.fs_manager import FileSystemManager
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
@@ -522,6 +523,22 @@ class VariableClTarget(ReadonlyVariable):
             short=self.Get('os_install_linux_shortname'),
             ver=self.Get('os_install_linux_ver'))
 
+        if self.Get('os_install_root_type') == "flash":
+            flashLabel = "{short}-{build}".format(
+                short="CL", build=self.Get('os_install_linux_build'))
+            disk = self.Get('os_install_disk_single')
+            fileSystem = "vfat"
+            systemId = FileSystemManager.supportFS.get(
+                'vfat', {}).get('msdos', '0b')
+            isFormat = self.GetBool('os_install_format_single_set')
+            partTable = self.select('os_disk_part',
+                                    os_disk_dev=disk, limit=1)
+            return FlashDistributive(
+                disk, mdirectory=DefaultMountPath.InstallMount,
+                check=True, fileSystem=fileSystem,
+                isFormat=isFormat, systemId=systemId,
+                rootLabel=flashLabel,
+                partitionTable=partTable)
         osInstallScratch = self.isTrue(self.Get('os_install_scratch'))
         mapDevId = dict(self.ZipVars('os_disk_dev', 'os_disk_id'))
         disk, mount, fileSystem, isFormat, partTable, systemId = \
@@ -534,15 +551,6 @@ class VariableClTarget(ReadonlyVariable):
             raise VariableError("Scratch is not supported")
         if self.Get('os_install_pxe') == "on":
             return PxeDistributive(self.Get('os_install_pxe_path'))
-        elif self.Get('os_install_root_type') == "flash":
-            flashLabel = "{short}-{build}".format(
-                short="CL", build=self.Get('os_install_linux_build'))
-            return FlashDistributive(
-                disk, mdirectory=DefaultMountPath.InstallMount,
-                check=True, fileSystem=fileSystem,
-                isFormat=isFormat, systemId=systemId,
-                rootLabel=flashLabel,
-                partitionTable=partTable)
         else:
             target = PartitionDistributive(
                 disk, mdirectory=DefaultMountPath.InstallMount,
