@@ -19,10 +19,10 @@ from os import path
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.variables.locale import Locale
 from calculate.lib.utils.files import readLinesFile, process
-from calculate.lib.utils.common import getValueFromCmdLine, getValueFromConfig
+from calculate.lib.utils.common import (getValueFromCmdLine, getValueFromConfig,
+                                        CmdlineParams)
 from pytz import timezone, country_timezones, UnknownTimeZoneError
 from datetime import datetime
-from operator import itemgetter
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 
@@ -93,7 +93,8 @@ class VariableOsInstallLocaleKeymap(LocaleVariable):
     def get(self):
         # get keymap from boot calculate param (keymap specified
         # by lang)
-        keymap = getValueFromCmdLine("calculate", 1)
+        keymap = getValueFromCmdLine(CmdlineParams.Calculate,
+                                     CmdlineParams.Keymap)
         if self.isLangExists(keymap):
             return self.getFieldByLang('keymap', keymap)
         return self.getFieldByLang("keymap",
@@ -145,7 +146,7 @@ class VariableOsInstallLocaleLang(LocaleVariable):
 
     def choice(self):
         return zip(self.Get('os_lang'),
-                          map(str, self.Get('os_lang', humanreadable=True)))
+                   map(str, self.Get('os_lang', humanreadable=True)))
 
 
 class VariableOsInstallLocaleLanguage(LocaleVariable):
@@ -188,6 +189,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
     type = 'choiceedit'
     metavalue = "TIMEZONE"
     opt = ["--timezone"]
+    locale_varname = 'os_install_locale_lang'
 
     def init(self):
         self.label = _("Timezone")
@@ -214,7 +216,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
                 tz = timezone(tzname)
                 strinfo = tz.localize(datetime.now()).strftime('%z')
                 yield (
-                tzname, "%s (%s:%s)" % (tzname, strinfo[:3], strinfo[-2:]))
+                    tzname, "%s (%s:%s)" % (tzname, strinfo[:3], strinfo[-2:]))
             except UnknownTimeZoneError:
                 pass
 
@@ -316,7 +318,7 @@ class VariableOsInstallClockTimezone(LocaleVariable):
             return int(strinfo[:3]), int("%s%s" % (strinfo[0], strinfo[-2:]))
 
         try:
-            lang = self.Get('os_install_locale_lang').split('_')[1]
+            lang = self.Get(self.locale_varname).split('_')[1]
             nativeTZ = map(lambda x: x.encode('utf-8'),
                            country_timezones[lang])
             source = nativeTZ + ["---"] + \
